package Moose::OldDocs;
{
  $Moose::OldDocs::VERSION = '0.03'; # TRIAL
}

# ABSTRACT: A distro that contains stubs for documentation which has moved.



=pod

=head1 NAME

Moose::OldDocs - A distro that contains stubs for documentation which has moved.

=head1 VERSION

version 0.03

=head1 DESCRIPTION

All of the recipes in the Moose cookbook were renamed. This distro provides
links for the old recipe names for metacpan and search.cpan.org. There is no
reason to install this distro.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2012 by Dave Rolsky.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut


__END__

